// Requires filter.js, where setSetings() is located
function postURL(n) {
  var url = $(location).attr('href');
  var form = document.getElementById("filter");
  form.r.value = n;
  form.submit();
}
function next(n){
  postURL(n);
}
function previous(n){
  if(n < 0){
    n = 0;}
  postURL(n);
}
